@@ -648,6 +648,7 @@ def standardized(
         all_metrics=not metrics,
         use_fiscal_period=True,
         include_preliminary=point_in_time,
+        include_xbrl=True,
     )
 
     data = _build_data_frame(data)
@@ -676,6 +677,7 @@ def standardized(
         index_columns = index_columns + ["date_reported"]
         data["date_downloaded"] = datetime.now()
     data = data.set_index(index_columns)
+    data = data.sort_index()
     return data
 
 
